CREATE SCHEMA [msn]
GO

CREATE TABLE [msn].[HistoricalPricesDaily] (
    [Symbol] [varchar](50) NOT NULL,
    [LoadDate] [date] NOT NULL,
    [LoadTime] [time](0) NOT NULL,
    [Date] [date] NOT NULL,
    [Open] [smallmoney] NULL,
    [High] [smallmoney] NULL,
    [Low] [smallmoney] NULL,
    [Close] [smallmoney] NULL,
    [Volume] [bigint] NULL,
  CONSTRAINT [PK_HistoricalPricesDaily_msn] PRIMARY KEY
(
    [Symbol],
    [Date],
    [LoadDate],
    [LoadTime]
)
)
GO

CREATE TABLE [msn].[HistoricalPricesWeekly] (
    [Symbol] [varchar](50) NOT NULL,
    [LoadDate] [date] NOT NULL,
    [LoadTime] [time](0) NOT NULL,
    [Date] [date] NOT NULL,
    [Open] [smallmoney] NULL,
    [High] [smallmoney] NULL,
    [Low] [smallmoney] NULL,
    [Close] [smallmoney] NULL,
    [Volume] [bigint] NULL,
  CONSTRAINT [PK_HistoricalPricesWeekly_msn] PRIMARY KEY
(
    [Symbol],
    [Date],
    [LoadDate],
    [LoadTime]
)
)
GO

CREATE TABLE [msn].[HistoricalPricesMonthly] (
    [Symbol] [varchar](50) NOT NULL,
    [LoadDate] [date] NOT NULL,
    [LoadTime] [time](0) NOT NULL,
    [Date] [date] NOT NULL,
    [Open] [smallmoney] NULL,
    [High] [smallmoney] NULL,
    [Low] [smallmoney] NULL,
    [Close] [smallmoney] NULL,
    [Volume] [bigint] NULL,
  CONSTRAINT [PK_HistoricalPricesMonthly_msn] PRIMARY KEY
(
    [Symbol],
    [Date],
    [LoadDate],
    [LoadTime]
)
)
GO

CREATE TABLE [msn].[IntradayPrices1m] (
    [Symbol] [varchar](50) NOT NULL,
    [LoadDate] [date] NOT NULL,
    [LoadTime] [time](0) NOT NULL,
    [Date] [datetime] NOT NULL,
    [Open] [smallmoney] NULL,
    [High] [smallmoney] NULL,
    [Low] [smallmoney] NULL,
    [Close] [smallmoney] NULL,
    [Volume] [int] NULL,
  CONSTRAINT [PK_IntradayPrices1m_msn] PRIMARY KEY
(
    [Symbol],
    [Date],
    [LoadDate],
    [LoadTime]
)
)
GO

CREATE TABLE [msn].[IntradayPrices5m] (
    [Symbol] [varchar](50) NOT NULL,
    [LoadDate] [date] NOT NULL,
    [LoadTime] [time](0) NOT NULL,
    [Date] [datetime] NOT NULL,
    [Open] [smallmoney] NULL,
    [High] [smallmoney] NULL,
    [Low] [smallmoney] NULL,
    [Close] [smallmoney] NULL,
    [Volume] [int] NULL,
  CONSTRAINT [PK_IntradayPrices5m_msn] PRIMARY KEY
(
    [Symbol],
    [Date],
    [LoadDate],
    [LoadTime]
)
)
GO

CREATE TABLE [msn].[IntradayPrices15m] (
    [Symbol] [varchar](50) NOT NULL,
    [LoadDate] [date] NOT NULL,
    [LoadTime] [time](0) NOT NULL,
    [Date] [datetime] NOT NULL,
    [Open] [smallmoney] NULL,
    [High] [smallmoney] NULL,
    [Low] [smallmoney] NULL,
    [Close] [smallmoney] NULL,
    [Volume] [int] NULL,
  CONSTRAINT [PK_IntradayPrices15m_msn] PRIMARY KEY
(
    [Symbol],
    [Date],
    [LoadDate],
    [LoadTime]
)
)
GO

CREATE TABLE [msn].[Quotes] (
    [Symbol] [varchar](50) NOT NULL,
    [MsnSymbol] [varchar](50) NULL,
    [LoadDate] [date] NOT NULL,
    [LoadTime] [time](0) NOT NULL,
    [MarketDate] [date] NOT NULL,
    [MarketTime] [time](0) NOT NULL,
    [Bid] [smallmoney] NULL,
    [Ask] [smallmoney] NULL,
    [BidSize] int NULL,
    [AskSize] int NULL,
    [Open] [smallmoney] NULL,
    [High] [smallmoney] NULL,
    [Low] [smallmoney] NULL,
    [Last] [smallmoney] NULL,
    [Volume] [bigint] NULL,
    [AvgVolume] [bigint] NULL,
    [LastPriceDate] [date] NULL,
    [LastPriceTime] [time] NULL,
    [PreviousClose] [smallmoney] NULL,
    [Change] [smallmoney] NULL,
    [ChangePercent] [float] NULL,
    [Post] [smallmoney] NULL,
    [PostChange] [smallmoney] NULL,
    [PostChangePercent] [float] NULL,
    [YearHigh] [smallmoney] NULL,
    [YearLow] [smallmoney] NULL,
    [PrCh1Mo] [float] NULL,
    [PrCh3Mo] [float] NULL,
    [PrCh6Mo] [float] NULL,
    [YRR] [float] NULL,
    [YTD] [float] NULL,
    [PE] [float] NULL,
    [DividendRate] [float] NULL,
    [DividendYield] [float] NULL,
    [MarketCap] [bigint] NULL,
    [Sym] [varchar](50) NULL,
    [FriendlyName] [nvarchar](50) NULL,
    [ShortName] [nvarchar](50) NULL,
    [Company] [nvarchar](50) NULL,
    [Market] [varchar](50) NULL,
    [Exchange] [varchar](50) NULL,
    [TimeZone] [varchar](50) NULL,
    [UtcOffset] [int] NULL,
    [InstrumentType] [varchar](50) NULL,
    [Currency] [varchar](50) NULL,
    [preIPO] [tinyint] NULL,
  CONSTRAINT [PK_Quotes_msn] PRIMARY KEY (
    [Symbol],
    [LoadDate],
    [LoadTime]
  )
)
GO

CREATE TABLE [msn].[OptionContracts] (
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [ContractName] [varchar](50) NOT NULL,
    [Symbol] [varchar](50) NOT NULL,
    [ExpDate] [date] NOT NULL,
    [Type] [char] (1) NOT NULL,
    [Strike] [smallmoney] NOT NULL,
    [PairContractName] [varchar](50) NOT NULL,
  CONSTRAINT [PK_OptionContracts_msn] PRIMARY KEY ([ID]),
  CONSTRAINT [IX_OptionContracts_ContractName_msn] UNIQUE ([ContractName])
)
GO

CREATE TABLE [msn].[Options] (
    [OptionContractID] [int] NOT NULL,
    [LoadDate] [date] NOT NULL,
    [LoadTime] [time](0) NOT NULL,
    [MarketDate] [date] NULL,
    [MarketTime] [time](0) NULL,
    [Bid] [smallmoney] NULL,
    [Ask] [smallmoney] NULL,
    [Last] [smallmoney] NULL,
    [Change] [smallmoney] NULL,
    [ChangePercent] [float] NULL,
    [Volume] [int] NULL,
    [OpenInterest] [int] NULL,
  CONSTRAINT [PK_Options_msn] PRIMARY KEY
(
    [OptionContractID],
    [LoadDate],
    [LoadTime]
)
)
GO

CREATE TABLE [msn].[OptionTypes] (
    [OptionType] [char] (1) NOT NULL,
    [Type] [varchar](4) NOT NULL,
  CONSTRAINT [PK_OptionTypes_msn] PRIMARY KEY ([OptionType]),
  CONSTRAINT [IX_OptionTypes_Type_msn] UNIQUE ([OptionType])
)
GO

ALTER TABLE [msn].[OptionContracts] ADD CONSTRAINT [FK_OptionContracts_OptionTypes_msn] FOREIGN KEY ([Type])
REFERENCES [msn].[OptionTypes] ([OptionType])
ON UPDATE CASCADE
ON DELETE CASCADE
GO

ALTER TABLE [msn].[Options] ADD CONSTRAINT [FK_Options_OptionContracts_msn] FOREIGN KEY ([OptionContractID])
REFERENCES [msn].[OptionContracts] ([ID])
ON UPDATE CASCADE
ON DELETE CASCADE
GO

INSERT [msn].[OptionTypes] ([OptionType], [Type]) VALUES (N'C', N'CALL')
INSERT [msn].[OptionTypes] ([OptionType], [Type]) VALUES (N'P', N'PUT')
GO
